@@ -724,9 +724,11 @@ void fillout_card(
 {
 	int		i;		/* item counter */
 
-	if (card)
+	if (card) {
+		card->disprow = card->row;
 		for (i=0; i < card->nitems; i++)
 			fillout_item(card, i, deps);
+	}
 	remake_section_popup(FALSE);
 }
 
